Learn R Programming

simitation (version 0.0.7)

internal.chisq.test.gf: Internal function for Chi-Squared Test of Goodness of Fit

Description

Computes the chi-squared test for the given categorical data.

Usage

internal.chisq.test.gf(x, hypothesized.probs = NULL, correct = TRUE)

Value

A data frame containing the test statistic, degrees of freedom, and p-value.

Arguments

x

A categorical variable.

hypothesized.probs

Hypothesized probabilities for each level of x.

correct

A logical indicating if a continuity correction should be applied.