Computes the chi-squared test for the given categorical data.
internal.chisq.test.gf(x, hypothesized.probs = NULL, correct = TRUE)A data frame containing the test statistic, degrees of freedom, and p-value.
A categorical variable.
Hypothesized probabilities for each level of x.
A logical indicating if a continuity correction should be applied.